==> jboss-cl-dist-2.0.6.GA-src.zip: jboss-cl-2.0.6.GA/classloading/src/test/java/org/jboss/test/classloading/metadata/xml/support/TestCapability.java <==
/*
* JBoss, Home of Professional Open Source
* Copyright 2007, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.test.classloading.metadata.xml.support;

import javax.xml.bind.annotation.XmlNsForm;
import javax.xml.bind.annotation.XmlRootElement;

import org.jboss.classloading.spi.dependency.Module;
import org.jboss.classloading.spi.metadata.Requirement;
import org.jboss.classloading.spi.metadata.helpers.AbstractCapability;
import org.jboss.xb.annotations.JBossXmlSchema;

@JBossXmlSchema(namespace="urn:jboss:test:classloading:capability:1.0", elementFormDefault=XmlNsForm.QUALIFIED)
@XmlRootElement(name="test")
public class TestCapability extends AbstractCapability
{
   private static final long serialVersionUID = -1L;

   public TestCapability()
   {
   }
   
   public TestCapability(String name, Object version)
   {
      super(name, version);
   }
   
   public boolean resolves(Module module, Requirement requirement)
   {
      return false;
   }
}

==> jboss-cl-dist-2.0.12.GA-src.zip: jboss-cl-2.0.12.GA/classloading/src/test/java/org/jboss/test/classloading/metadata/xml/support/TestCapability.java <==
/*
* JBoss, Home of Professional Open Source
* Copyright 2007, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.test.classloading.metadata.xml.support;

import javax.xml.bind.annotation.XmlNsForm;
import javax.xml.bind.annotation.XmlRootElement;

import org.jboss.classloading.spi.dependency.Module;
import org.jboss.classloading.spi.metadata.Requirement;
import org.jboss.classloading.spi.metadata.helpers.AbstractCapability;
import org.jboss.xb.annotations.JBossXmlSchema;

@JBossXmlSchema(namespace="urn:jboss:test:classloading:capability:1.0", elementFormDefault=XmlNsForm.QUALIFIED)
@XmlRootElement(name="test")
public class TestCapability extends AbstractCapability
{
   private static final long serialVersionUID = -1L;

   public TestCapability()
   {
   }
   
   public TestCapability(String name, Object version)
   {
      super(name, version);
   }
   
   public boolean resolves(Module reqModule, Requirement requirement)
   {
      return false;
   }
}
